@@ -6,6 +6,9 @@
 
 from __future__ import print_function
 import IMP.algebra
+import sys
+
+IMP.setup_from_argv(sys.argv, "grid space")
 
 # create a unit grid with its origin at 0,0,0
 g = IMP.algebra.SparseUnboundedIntGrid3D(1, IMP.algebra.Vector3D(0, 0, 0))
@@ -31,4 +34,5 @@ for i in g.get_extended_indexes(IMP.algebra.get_bounding_box(s)):
         g.add_voxel(i, -1)
         in_count += 1
 
-print("There are", len(g.get_all_indexes()), "distinct values", count, in_count)
+print("There are", len(g.get_all_indexes()), "distinct values",
+      count, in_count)
